
Contributors
============

A total of 13 people contributed to this release.  People with a "+" by their
names contributed a patch for the first time.

* Aaron Meurer
* Andrew Nelson
* Charles Harris
* Kevin Sheppard
* Matti Picus
* Nathan Goldbaum
* Peter Hawkins
* Ralf Gommers
* Randy Eckenrode +
* Sam James +
* Sebastian Berg
* Tyler Reddy
* dependabot[bot]

Pull requests merged
====================

A total of 19 pull requests were merged for this release.

* `#24148 <https://github.com/numpy/numpy/pull/24148>`__: MAINT: prepare 1.25.x for further development
* `#24174 <https://github.com/numpy/numpy/pull/24174>`__: ENH: Improve clang-cl compliance
* `#24179 <https://github.com/numpy/numpy/pull/24179>`__: MAINT: Upgrade various build dependencies.
* `#24182 <https://github.com/numpy/numpy/pull/24182>`__: BLD: use ``-ftrapping-math`` with Clang on macOS
* `#24183 <https://github.com/numpy/numpy/pull/24183>`__: BUG: properly handle negative indexes in ufunc_at fast path
* `#24184 <https://github.com/numpy/numpy/pull/24184>`__: BUG: PyObject_IsTrue and PyObject_Not error handling in setflags
* `#24185 <https://github.com/numpy/numpy/pull/24185>`__: BUG: histogram small range robust
* `#24186 <https://github.com/numpy/numpy/pull/24186>`__: MAINT: Update meson.build files from main branch
* `#24234 <https://github.com/numpy/numpy/pull/24234>`__: MAINT: exclude min, max and round from ``np.__all__``
* `#24241 <https://github.com/numpy/numpy/pull/24241>`__: MAINT: Dependabot updates
* `#24242 <https://github.com/numpy/numpy/pull/24242>`__: BUG: Fix the signature for np.array_api.take
* `#24243 <https://github.com/numpy/numpy/pull/24243>`__: BLD: update OpenBLAS to an intermeidate commit
* `#24244 <https://github.com/numpy/numpy/pull/24244>`__: BUG: Fix reference count leak in str(scalar).
* `#24245 <https://github.com/numpy/numpy/pull/24245>`__: BUG: fix invalid function pointer conversion error
* `#24255 <https://github.com/numpy/numpy/pull/24255>`__: BUG: Factor out slow ``getenv`` call used for memory policy warning
* `#24292 <https://github.com/numpy/numpy/pull/24292>`__: CI: correct URL in cirrus.star [skip cirrus]
* `#24293 <https://github.com/numpy/numpy/pull/24293>`__: BUG: Fix C types in scalartypes
* `#24294 <https://github.com/numpy/numpy/pull/24294>`__: BUG: do not modify the input to ufunc_at
* `#24295 <https://github.com/numpy/numpy/pull/24295>`__: BUG: Further fixes to indexing loop and added tests
